package com.antai.sport.http.server.server.api.business.series.controller;

import com.antai.sport.http.server.common.base.Result;
import com.antai.sport.http.server.server.api.business.series.dto.*;
import com.antai.sport.http.server.server.api.business.series.service.SeriesService;
import com.antai.sport.http.server.server.api.business.series.vo.*;
import com.antai.sport.http.server.server.api.common.dto.CyclingDataDTO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

import static com.antai.sport.http.server.common.util.ResultUtil.success;

@RestController
@RequestMapping("series")
@Api(tags = {"系列赛接口"})
public class SeriesController {
    @Resource
    private SeriesService seriesService;

    @GetMapping("list")
    @ApiOperation(value = "1.查询系列赛列表")
    public ResponseEntity<Result<List<SeriesListVO>>> getSeriesList() {
        return success(seriesService.getSeriesList(null));
    }

    @PostMapping("list")
    @ApiOperation(value = "1.查询系列赛列表带名称搜索")
    public ResponseEntity<Result<List<SeriesListVO>>> getSeriesList(@RequestBody SeriesListQueryDTO dto) {
        return success(seriesService.getSeriesList(dto));
    }

    @GetMapping("{id}/{sportUserId}")
    @ApiOperation(value = "2.查询系列赛详情")
    public ResponseEntity<Result<SeriesDetailsVO>> getSeriesDetails(@PathVariable("id") Long id, @PathVariable(
            "sportUserId") Long sportUserId) {
        return success(seriesService.getSeriesDetails(id, sportUserId));
    }

    @GetMapping("apply/preload/{seriesId}/{sportUserId}")
    @ApiOperation(value = "3.预加载报名信息方法")
    public ResponseEntity<Result<SeriesApplyPreLoadVO>> getSeresApplyPreLoadInfo(@PathVariable("seriesId") Long seriesId, @PathVariable("sportUserId") Long sportUserId) {
        return success(seriesService.getSeresApplyPreLoadInfo(sportUserId, seriesId));
    }

    @PostMapping("apply")
    @ApiOperation(value = "4.报名方法")
    public ResponseEntity<Result> seriesApply(@RequestBody SeriesApplyDTO dto) {
        seriesService.seriesApply(dto);
        return success();
    }

    @GetMapping("qualifying/{roundId}/{areaId}/{sportUserId}")
    @ApiOperation(value = "5.查询预选赛轮次主页数据")
    public ResponseEntity<Result<SeriesQualifyingMatchHomeVO>> getSeriesQualifyingMatchHomeData(@PathVariable(
            "roundId") Long roundId, @PathVariable("areaId") Long areaId, @PathVariable("sportUserId") Long sportUserId) {
        return success(seriesService.getSeriesQualifyingMatchHomeData(roundId, areaId, sportUserId));
    }

    @PostMapping("qualifying/round/area/rank")
    @ApiOperation(value = "6.查询预选赛轮次大区排名")
    public ResponseEntity<Result<List<SeriesQualifyingMatchRankVO>>> getSeriesQualifyingMatchRank(@RequestBody SeriesQualifyingMatchRankDTO dto) {
        return success(seriesService.getSeriesQualifyingMatchRank(dto));
    }

    @ApiOperation("7.预选赛加入比赛信息初始化")
    @PostMapping("qualifying/match/init")
    public ResponseEntity<Result<SeriesMatchRecordInitVO>> seriesQualifyingMatchRecordInit(@RequestBody SeriesQualifyingMatchRecordInitDTO dto) {
        return success(seriesService.seriesQualifyingMatchRecordInit(dto));
    }

    @ApiOperation("20.系列赛比赛结果上传")
    @PostMapping("/record/upload")
    public ResponseEntity<Result> recordUpload(@RequestBody List<CyclingDataDTO> dataList) {
        seriesService.recordUpload(dataList);
        return success();
    }

    @ApiOperation("8.获取淘汰赛首页数据")
    @GetMapping("knockout/match/{roundId}/{sportUserId}")
    public ResponseEntity<Result<SeriesKnockoutMatchHomeVO>> getSeriesKnockoutMatchHomeData(
            @PathVariable("roundId") Long roundId,
            @PathVariable("sportUserId") Long sportUserId) {
        return success(seriesService.getSeriesKnockoutMatchHomeData(roundId, sportUserId));
    }

    @ApiOperation("9.查询淘汰赛玩家列表")
    @PostMapping("knockout/match/user")
    public ResponseEntity<Result<List<SeriesKnockoutMatchUserVO>>> getSeriesKnockoutMatchUserList(@RequestBody SeriesKnockoutMatchUserDTO dto) {
        return success(seriesService.getSeriesKnockoutMatchUserList(dto));
    }

    @ApiOperation("10.查询淘汰赛排行列表")
    @PostMapping("knockout/match/rank")
    public ResponseEntity<Result<List<SeriesKnockoutMatchRankVO>>> getSeriesKnockoutMatchRankList(@RequestBody SeriesKnockoutMatchRankDTO dto) {
        return success(seriesService.getSeriesKnockoutMatchRankList(dto));
    }

    @ApiOperation("11.淘汰赛玩家数据初始化")
    @PostMapping("knockout/match/init")
    public ResponseEntity<Result<SeriesMatchRecordInitVO>> seriesKnockoutMatchRecordInit(@RequestBody SeriesKnockoutMatchRecordInitDTO dto) {
        return success(seriesService.seriesKnockoutMatchRecordInit(dto));
    }

    @ApiOperation("19.游戏服务端加载未完成比赛使用")
    @PostMapping("match/for/server")
    public ResponseEntity<Result<List<SeriesMatchForGameServerVO>>> getSeriesMatchForGameServer() {
        return success(seriesService.getSeriesMatchForGameServer());
    }

    @ApiOperation("12.获取系列赛完结结果")
    @PostMapping("result/{seriesId}/{sportUserId}")
    public ResponseEntity<Result<List<SeriesMatchResultVO>>> getSeriesMatchResult(@PathVariable("seriesId") Long seriesId,
                                                                                  @PathVariable("sportUserId") Long sportUserId) {
        return success(seriesService.getSeriesMatchResult(seriesId, sportUserId));
    }


}
